=============
Tinned Python
=============


.. image:: https://img.shields.io/pypi/v/tinned_python.svg
        :target: https://pypi.python.org/pypi/tinned_python

.. image:: https://github.com/tmfnll/tinned_python/workflows/Python%20package/badge.svg
        :target: https://github.com/tmfnll/tinned_python/actions?query=workflow%3A%22Python+package%22

.. image:: https://readthedocs.org/projects/tinned-python/badge/?version=latest
        :target: https://tinned-python.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/tmfnll/tinned_python/shield.svg
     :target: https://pyup.io/repos/github/tmfnll/tinned_python/
     :alt: Updates



Python data, in a tin


* Free software: MIT license
* Documentation: https://tinned-python.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
